@@ -26,12 +26,13 @@ class BotTelegramPlugin:
 
     def _find_chat_id(self, group: str) -> str:
         objs = self.bot.get_updates()
-        print(objs)
+
         for object in objs:
             obj = object.__dict__
             message = obj["message"]
-            if message.chat.title == group:
-                return message.chat.id
+            if message is not None and message.chat is not None:
+                if message.chat.title == group:
+                    return message.chat.id
         return None
 
     def _user_for_mentions(self, username: List[str]) -> str or List[str]:
